<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pt" sourcelanguage="en">
<context>
    <name>Alert</name>
    <message>
        <source>Close (%1)</source>
        <translation>Fechar (%1)</translation>
    </message>
    <message>
        <source>Collapse</source>
        <translation>Minimizar</translation>
    </message>
    <message>
        <source>Expand</source>
        <translation>Expandir</translation>
    </message>
</context>
<context>
    <name>AlertLayer</name>
    <message>
        <source>Dismiss Alert</source>
        <translation>Descartar o Alerta</translation>
    </message>
    <message>
        <source>Ctrl+D</source>
        <translation>Ctrl+D</translation>
    </message>
</context>
<context>
    <name>DailyProgress</name>
    <message numerus="yes">
        <source>%Ln word(s)</source>
        <translation>
            <numerusform>%Ln palavra</numerusform>
            <numerusform>%Ln palavras</numerusform>
            <numerusform>%Ln palavras</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%Ln minute(s)</source>
        <translation>
            <numerusform>%Ln minuto</numerusform>
            <numerusform>%Ln minutos</numerusform>
            <numerusform>%Ln minutos</numerusform>
        </translation>
    </message>
    <message>
        <source>0%</source>
        <translation>0%</translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln minute(s)</source>
        <translation>
            <numerusform>%L1% de %Ln minuto</numerusform>
            <numerusform>%L1% de %Ln minutos</numerusform>
            <numerusform>%L1% de %Ln minutos</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%L1% of %Ln word(s)</source>
        <translation>
            <numerusform>%L1% de %Ln palavra</numerusform>
            <numerusform>%L1% de %Ln palavras</numerusform>
            <numerusform>%L1% de %Ln palavras</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>DailyProgressDialog</name>
    <message>
        <source>Daily Progress</source>
        <translation>Progresso Diário</translation>
    </message>
    <message>
        <source>Longest streak</source>
        <translation>Período mais longo</translation>
    </message>
    <message>
        <source>Current streak</source>
        <translation>Período atual</translation>
    </message>
    <message>
        <source>N/A</source>
        <translation>N/A</translation>
    </message>
    <message numerus="yes">
        <source>%n day(s)</source>
        <translation>
            <numerusform>%n dia</numerusform>
            <numerusform>%n dias</numerusform>
            <numerusform>%n dias</numerusform>
        </translation>
    </message>
    <message>
        <source>%1 &amp;ndash; %2</source>
        <translation>%1 &amp;ndash; %2</translation>
    </message>
</context>
<context>
    <name>DailyProgressLabel</name>
    <message>
        <source>%L1% of daily goal</source>
        <translation>%L1% do objetivo diário</translation>
    </message>
</context>
<context>
    <name>DictionaryDialog</name>
    <message>
        <source>Set Language</source>
        <translation>Definir Idioma</translation>
    </message>
</context>
<context>
    <name>Document</name>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sem título %1)</translation>
    </message>
    <message>
        <source>%1 (Read-Only)</source>
        <translation>%1 (Apenas Leitura)</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to save &apos;%1&apos;.</source>
        <translation>Não foi possível guardar &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Save File As</source>
        <translation>Guardar Como</translation>
    </message>
    <message>
        <source>Unable to overwrite &apos;%1&apos;.</source>
        <translation>Não foi possível substituir &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Rename File</source>
        <translation>Alterar o Nome do Ficheiro</translation>
    </message>
    <message>
        <source>Unable to rename &apos;%1&apos;.</source>
        <translation>Não foi possível alterar o nome de &quot;%1&quot;.</translation>
    </message>
    <message>
        <source>Reload File?</source>
        <translation>Carregar de novo o ficheiro?</translation>
    </message>
    <message>
        <source>Reload the file &apos;%1&apos; from disk?</source>
        <translation>Carregar de novo o ficheiro &quot;%1&quot; do disco?</translation>
    </message>
    <message>
        <source>All unsaved changes will be lost.</source>
        <translation>Todas as alterações não guardadas serão perdidas.</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Carregar de novo</translation>
    </message>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Saving as plain text will discard all formatting. Discard formatting?</source>
        <translation>Guardar como texto simples descartará toda a formatação. Descartar a formatação?</translation>
    </message>
</context>
<context>
    <name>DocumentWatcher</name>
    <message>
        <source>File Changed</source>
        <translation>Ficheiro Alterado</translation>
    </message>
    <message>
        <source>The file &apos;%1&apos; was changed by another program.</source>
        <translation>O ficheiro &quot;%1&quot; foi alterado por outro programa.</translation>
    </message>
    <message>
        <source>Do you want to reload the file?</source>
        <translation>Carregar de novo o ficheiro?</translation>
    </message>
    <message>
        <source>Reload</source>
        <translation>Carregar de novo</translation>
    </message>
    <message>
        <source>Ignore</source>
        <translation>Ignorar</translation>
    </message>
    <message>
        <source>File Deleted</source>
        <translation>Ficheiro Eliminado</translation>
    </message>
    <message>
        <source>The file %1 was deleted by another program.</source>
        <translation>O ficheiro &quot;%1&quot; foi eliminado por outro programa.</translation>
    </message>
    <message>
        <source>Do you want to save or close the file?</source>
        <translation>Gravar ou fechar o ficheiro?</translation>
    </message>
</context>
<context>
    <name>DocxReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o ficheiro.</translation>
    </message>
</context>
<context>
    <name>FindDialog</name>
    <message>
        <source>Search for:</source>
        <translation>Procurar por:</translation>
    </message>
    <message>
        <source>Replace with:</source>
        <translation>Substituir por:</translation>
    </message>
    <message>
        <source>Ignore case</source>
        <translation>Ignorar maiúsculas</translation>
    </message>
    <message>
        <source>Whole words only</source>
        <translation>Apenas palavras inteiras</translation>
    </message>
    <message>
        <source>Regular expressions</source>
        <translation>Expressões regulares</translation>
    </message>
    <message>
        <source>Search up</source>
        <translation>Para cima</translation>
    </message>
    <message>
        <source>Search down</source>
        <translation>Para baixo</translation>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Procurar</translation>
    </message>
    <message>
        <source>&amp;Replace</source>
        <translation>&amp;Substituir</translation>
    </message>
    <message>
        <source>Replace &amp;All</source>
        <translation>Substituir &amp;Tudo</translation>
    </message>
    <message>
        <source>Find</source>
        <translation>Procurar</translation>
    </message>
    <message>
        <source>Replace</source>
        <translation>Substituir</translation>
    </message>
    <message numerus="yes">
        <source>Replace %n instance(s)?</source>
        <translation>
            <numerusform>Substituir %n ocorrência?</numerusform>
            <numerusform>Substituir %n ocorrências?</numerusform>
            <numerusform>Substituir %n ocorrências?</numerusform>
        </translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Phrase not found.</source>
        <translation>A frase não foi encontrada.</translation>
    </message>
</context>
<context>
    <name>FormatManager</name>
    <message>
        <source>OpenDocument Text</source>
        <translation>Texto OpenDocument</translation>
    </message>
    <message>
        <source>Office Open XML</source>
        <translation>Office Open XML</translation>
    </message>
    <message>
        <source>Rich Text Format</source>
        <translation>Rich Text Format</translation>
    </message>
    <message>
        <source>Plain Text</source>
        <translation>Texto Simples</translation>
    </message>
    <message>
        <source>All Files</source>
        <translation>Todos os Ficheiros</translation>
    </message>
    <message>
        <source>All Supported Files</source>
        <translation>Todos os Ficheiros Suportados</translation>
    </message>
    <message>
        <source>OpenDocument Flat XML</source>
        <translation>OpenDocument Flat XML</translation>
    </message>
</context>
<context>
    <name>Highlighter</name>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Check Spelling...</source>
        <translation>Verificação Ortográfica...</translation>
    </message>
    <message>
        <source>(No suggestions found)</source>
        <translation>(Nenhuma sugestão encontrada)</translation>
    </message>
</context>
<context>
    <name>ImageButton</name>
    <message>
        <source>Open Image</source>
        <translation>Abrir Imagem</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Imagens</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Selecionar a língua do programa:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Língua do sistema&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Nota</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>Por favor reinicie o programa para que a alteração da língua surta efeito.</translation>
    </message>
</context>
<context>
    <name>OdtReader</name>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o ficheiro.</translation>
    </message>
</context>
<context>
    <name>PreferencesDialog</name>
    <message>
        <source>Preferences</source>
        <translation>Preferências</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Geral</translation>
    </message>
    <message>
        <source>Statistics</source>
        <translation>Estatísticas</translation>
    </message>
    <message>
        <source>Toolbar</source>
        <translation>Barra de Ferramentas</translation>
    </message>
    <message>
        <source>Spell Checking</source>
        <translation>Verificação Ortográfica</translation>
    </message>
    <message>
        <source>Select Dictionary</source>
        <translation>Selecionar o Dicionário</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>Unable to open archive.</source>
        <translation>Não foi possível abrir o ficheiro.</translation>
    </message>
    <message>
        <source>The archive does not contain a usable dictionary.</source>
        <translation>O ficheiro não contém nenhum dicionário utilizável.</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Shortcuts</source>
        <translation>Atalhos</translation>
    </message>
    <message>
        <source>One or more shortcuts conflict. Do you wish to proceed?</source>
        <translation>Pelo menos um dos atalhos está em conflito. Continuar?</translation>
    </message>
    <message>
        <source>The dictionary &quot;%1&quot; already exists. Do you want to replace it?</source>
        <translation>O dicionário &quot;%1&quot; já existe. Deseja substituí-lo?</translation>
    </message>
    <message>
        <source>Daily Goal</source>
        <translation>Objetivo Diário</translation>
    </message>
    <message>
        <source>None</source>
        <translation>Nenhum</translation>
    </message>
    <message>
        <source>Minutes:</source>
        <translation>Minutos:</translation>
    </message>
    <message>
        <source>Words:</source>
        <translation>Palavras:</translation>
    </message>
    <message>
        <source>Editing</source>
        <translation>Edição</translation>
    </message>
    <message>
        <source>Always vertically center</source>
        <translation>Centrar sempre na vertical</translation>
    </message>
    <message>
        <source>Block insertion cursor</source>
        <translation>Cursor de bloco de inserção</translation>
    </message>
    <message>
        <source>Smooth fonts</source>
        <translation>Tipos de letra suavizados</translation>
    </message>
    <message>
        <source>Typewriter sounds</source>
        <translation>Ruídos de máquina de escrever</translation>
    </message>
    <message>
        <source>Smart quotes:</source>
        <translation>Aspas curvas e angulares:</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duplas</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>Scenes</source>
        <translation>Cenas</translation>
    </message>
    <message>
        <source>Divider:</source>
        <translation>Divisor:</translation>
    </message>
    <message>
        <source>Saving</source>
        <translation>A gravar</translation>
    </message>
    <message>
        <source>Remember cursor position</source>
        <translation>Memorizar a posição do cursor</translation>
    </message>
    <message>
        <source>Word count</source>
        <translation>Número de palavras</translation>
    </message>
    <message>
        <source>Page count</source>
        <translation>Número de páginas</translation>
    </message>
    <message>
        <source>Paragraph count</source>
        <translation>Número de parágrafos</translation>
    </message>
    <message>
        <source>Character count</source>
        <translation>Número de caracteres</translation>
    </message>
    <message>
        <source>Characters:</source>
        <translation>Caracteres:</translation>
    </message>
    <message>
        <source>Paragraphs:</source>
        <translation>Parágrafos:</translation>
    </message>
    <message>
        <source>Word Count Algorithm</source>
        <translation>Algoritmo de Contagem de Palavras</translation>
    </message>
    <message>
        <source>Reset daily progress for today to zero?</source>
        <translation>Repor a zero o progresso diário de hoje?</translation>
    </message>
    <message>
        <source>Write byte order mark in plain text files</source>
        <translation>Incluir marca de ordem de byte em ficheiros de texto simples</translation>
    </message>
    <message>
        <source>Default format:</source>
        <translation>Formato padrão:</translation>
    </message>
    <message>
        <source>Reset Today</source>
        <translation>Repor Hoje</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Histórico</translation>
    </message>
    <message>
        <source>Remember history</source>
        <translation>Lembrar histórico</translation>
    </message>
    <message>
        <source>Show streaks</source>
        <translation>Mostrar períodos</translation>
    </message>
    <message>
        <source>Minimum progress for streaks:</source>
        <translation>Progresso mínimo para períodos:</translation>
    </message>
    <message>
        <source>Detect word boundaries</source>
        <translation>Detetar o fim das palavras</translation>
    </message>
    <message>
        <source>Divide character count by six</source>
        <translation>Dividir contagem do número de caracteres por seis</translation>
    </message>
    <message>
        <source>Count each letter as a word</source>
        <translation>Contar cada letra como uma palavra</translation>
    </message>
    <message>
        <source>Page Count Algorithm</source>
        <translation>Algoritmo de Contagem das Páginas</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>Estilo</translation>
    </message>
    <message>
        <source>Icons Only</source>
        <translation>Apenas os Ícones</translation>
    </message>
    <message>
        <source>Text Only</source>
        <translation>Apenas o Texto</translation>
    </message>
    <message>
        <source>Text Alongside Icons</source>
        <translation>Texto ao Lado dos Ícones</translation>
    </message>
    <message>
        <source>Text Under Icons</source>
        <translation>Texto por Baixo dos Ícones</translation>
    </message>
    <message>
        <source>Text Position:</source>
        <translation>Posição do Texto:</translation>
    </message>
    <message>
        <source>Actions</source>
        <translation>Ações</translation>
    </message>
    <message>
        <source>Move Up</source>
        <translation>Para cima</translation>
    </message>
    <message>
        <source>Move Down</source>
        <translation>Para baixo</translation>
    </message>
    <message>
        <source>Add Separator</source>
        <translation>Adicionar Separador</translation>
    </message>
    <message>
        <source>Command</source>
        <translation>Comando</translation>
    </message>
    <message>
        <source>Shortcut</source>
        <translation>Atalho</translation>
    </message>
    <message>
        <source>Action</source>
        <translation>Ação</translation>
    </message>
    <message>
        <source>Check spelling as you type</source>
        <translation>Verificar ortografia ao escrever</translation>
    </message>
    <message>
        <source>Ignore words in UPPERCASE</source>
        <translation>Ignorar palavras em MAIÚSCULAS</translation>
    </message>
    <message>
        <source>Ignore words with numbers</source>
        <translation>Ignorar palavras com números</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Língua</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Adicionar</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Personal Dictionary</source>
        <translation>Dicionário Definido pelo Utilizador</translation>
    </message>
    <message>
        <source>Remove current dictionary?</source>
        <translation>Remover o dicionário atual?</translation>
    </message>
    <message>
        <source>User Interface</source>
        <translation>Interface do Utilizador</translation>
    </message>
    <message>
        <source>Always show scrollbar</source>
        <translation>Mostrar sempre a barra de deslocamento</translation>
    </message>
    <message>
        <source>Always show top bar</source>
        <translation>Mostrar sempre a barra superior</translation>
    </message>
    <message>
        <source>Always show bottom bar</source>
        <translation>Mostrar sempre a barra inferior</translation>
    </message>
</context>
<context>
    <name>RtfReader</name>
    <message>
        <source>Not a supported RTF file.</source>
        <translation>Não é um ficheiro RTF suportado.</translation>
    </message>
</context>
<context>
    <name>RtfTokenizer</name>
    <message>
        <source>Unexpectedly reached end of file.</source>
        <translation>Final do ficheiro atingido inesperadamente.</translation>
    </message>
</context>
<context>
    <name>SceneList</name>
    <message>
        <source>Ctrl+Shift+Down</source>
        <translation>Ctrl+Shift+Seta para Baixo</translation>
    </message>
    <message>
        <source>Move Scenes Up</source>
        <translation>Deslocar Cenas para Cima</translation>
    </message>
    <message>
        <source>Ctrl+Shift+Up</source>
        <translation>Ctrl+Shift+Seta para Cima</translation>
    </message>
    <message>
        <source>Toggle Scene List</source>
        <translation>Mostrar/Ocultar Lista de Cenas</translation>
    </message>
    <message>
        <source>Shift+F4</source>
        <translation>Shift+F4</translation>
    </message>
    <message>
        <source>Show scene list (%1)</source>
        <translation>Mostrar a lista de cenas (%1)</translation>
    </message>
    <message>
        <source>Hide scene list (%1)</source>
        <translation>Esconder a lista de cenas (%1)</translation>
    </message>
    <message>
        <source>Filter</source>
        <translation>Filtrar</translation>
    </message>
    <message>
        <source>Move Scenes Down</source>
        <translation>Deslocar Cenas para Baixo</translation>
    </message>
    <message>
        <source>Resize scene list</source>
        <translation>Alterar o tamanho da lista</translation>
    </message>
</context>
<context>
    <name>Session</name>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
</context>
<context>
    <name>SessionManager</name>
    <message>
        <source>Manage Sessions</source>
        <translation>Organizar as Sessões</translation>
    </message>
    <message>
        <source>S&amp;essions</source>
        <translation>S&amp;essões</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Rename</source>
        <translation>Alterar o Nome</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Switch To</source>
        <translation>Abrir a Sessão</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova Sessão</translation>
    </message>
    <message>
        <source>Duplicate Session</source>
        <translation>Duplicar sessão</translation>
    </message>
    <message>
        <source>Rename Session</source>
        <translation>Alterar Nome da Sessão</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete selected session?</source>
        <translation>Eliminar a sessão selecionada ?</translation>
    </message>
    <message>
        <source>Session name:</source>
        <translation>Nome da sessão:</translation>
    </message>
    <message>
        <source>Sorry</source>
        <translation>Desculpe</translation>
    </message>
    <message>
        <source>The requested session name is already in use.</source>
        <translation>O nome da sessão introduzido já está a ser utilizado.</translation>
    </message>
    <message>
        <source>&amp;New...</source>
        <translation>&amp;Nova...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;Manage...</source>
        <translation>&amp;Gerir...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+M</source>
        <translation>Ctrl+Shift+M</translation>
    </message>
</context>
<context>
    <name>ShortcutEdit</name>
    <message>
        <source>Clear</source>
        <translation>Limpar</translation>
    </message>
    <message>
        <source>Reset to Default</source>
        <translation>Repor os Valores Padrão</translation>
    </message>
    <message>
        <source>Shortcut:</source>
        <translation>Atalho:</translation>
    </message>
</context>
<context>
    <name>SmartQuote</name>
    <message>
        <source>Replacing quotation marks...</source>
        <translation>A substituir as aspas...</translation>
    </message>
    <message>
        <source>Please Wait</source>
        <translation>Por Favor Aguarde</translation>
    </message>
</context>
<context>
    <name>SpellChecker</name>
    <message>
        <source>Check Spelling</source>
        <translation>Verificação da Ortografia</translation>
    </message>
    <message>
        <source>&amp;Add</source>
        <translation>&amp;Adicionar</translation>
    </message>
    <message>
        <source>&amp;Ignore</source>
        <translation>&amp;Ignorar</translation>
    </message>
    <message>
        <source>I&amp;gnore All</source>
        <translation>I&amp;gnorar Tudo</translation>
    </message>
    <message>
        <source>&amp;Change</source>
        <translation>&amp;Alterar</translation>
    </message>
    <message>
        <source>C&amp;hange All</source>
        <translation>A&amp;lterar Tudo</translation>
    </message>
    <message>
        <source>Not in dictionary:</source>
        <translation>Não consta do dicionário:</translation>
    </message>
    <message>
        <source>Change to:</source>
        <translation>Alterar para:</translation>
    </message>
    <message>
        <source>Checking spelling...</source>
        <translation>Verificação da ortografia...</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>Cancelar</translation>
    </message>
    <message>
        <source>Please wait</source>
        <translation>Por favor aguarde</translation>
    </message>
    <message>
        <source>Continue checking at beginning of file?</source>
        <translation>Continuar a verificação do início do ficheiro?</translation>
    </message>
    <message>
        <source>Spell check complete.</source>
        <translation>A verificação da ortografia está concluída.</translation>
    </message>
</context>
<context>
    <name>SymbolsDialog</name>
    <message>
        <source>Symbols</source>
        <translation>Símbolos</translation>
    </message>
    <message>
        <source>Recently used symbols</source>
        <translation>Símbolos utilizados recentemente</translation>
    </message>
    <message>
        <source>All symbols</source>
        <translation>Todos os símbolos</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Detalhes</translation>
    </message>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>Insert</source>
        <translation>Inserir</translation>
    </message>
</context>
<context>
    <name>SymbolsModel</name>
    <message>
        <source>Blocks</source>
        <translation>Blocos</translation>
    </message>
    <message>
        <source>Scripts</source>
        <translation>Guiões</translation>
    </message>
</context>
<context>
    <name>Theme</name>
    <message>
        <source>Untitled %1</source>
        <translation>Sem título %1</translation>
    </message>
</context>
<context>
    <name>ThemeDialog</name>
    <message>
        <source>Name:</source>
        <translation>Nome:</translation>
    </message>
    <message>
        <source>No Image</source>
        <translation>Sem Imagem</translation>
    </message>
    <message>
        <source>Tiled</source>
        <translation>Em mosaico</translation>
    </message>
    <message>
        <source>Centered</source>
        <translation>Centrada</translation>
    </message>
    <message>
        <source>Stretched</source>
        <translation>Esticada</translation>
    </message>
    <message>
        <source>Scaled</source>
        <translation>Ampliada</translation>
    </message>
    <message>
        <source>Zoomed</source>
        <translation>Ampliada e cortada</translation>
    </message>
    <message>
        <source>Opacity:</source>
        <translation>Opacidade:</translation>
    </message>
    <message>
        <source>Position:</source>
        <translation>Posição:</translation>
    </message>
    <message>
        <source>Width:</source>
        <translation>Largura:</translation>
    </message>
    <message>
        <source>Round Text Background Corners</source>
        <translation>Cantos Arredondados na Folha</translation>
    </message>
    <message>
        <source>Radius:</source>
        <translation>Raio:</translation>
    </message>
    <message>
        <source>Blur Text Background</source>
        <translation>Desfocar Folha</translation>
    </message>
    <message>
        <source>Text Background Drop Shadow</source>
        <translation>Sombra da Folha</translation>
    </message>
    <message>
        <source>Vertical Offset:</source>
        <translation>Deslocamento Vertical:</translation>
    </message>
    <message>
        <source>Margins</source>
        <translation>Margens</translation>
    </message>
    <message>
        <source>Window:</source>
        <translation>Janela:</translation>
    </message>
    <message>
        <source>Page:</source>
        <translation>Página:</translation>
    </message>
    <message>
        <source>Indent first line</source>
        <translation>Indentar primeira linha</translation>
    </message>
    <message>
        <source>Above:</source>
        <translation>Em cima:</translation>
    </message>
    <message>
        <source>Below:</source>
        <translation>Em baixo:</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Edit Theme</source>
        <translation>Editar Tema</translation>
    </message>
    <message>
        <source>Window Background</source>
        <translation>Fundo da Janela</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Posicionamento:</translation>
    </message>
    <message>
        <source>Color:</source>
        <translation>Cor:</translation>
    </message>
    <message>
        <source>Image:</source>
        <translation>Imagem:</translation>
    </message>
    <message>
        <source> pixels</source>
        <translation> píxeis</translation>
    </message>
    <message>
        <source>Left</source>
        <translation>Esquerda</translation>
    </message>
    <message>
        <source>Text Background</source>
        <translation>Folha</translation>
    </message>
    <message>
        <source>Right</source>
        <translation>Direita</translation>
    </message>
    <message>
        <source>Text</source>
        <translation>Texto</translation>
    </message>
    <message>
        <source>Font:</source>
        <translation>Tipo de letra:</translation>
    </message>
    <message>
        <source>Misspelled:</source>
        <translation>Erros:</translation>
    </message>
    <message>
        <source>Line Spacing</source>
        <translation>Espaço Entre Linhas</translation>
    </message>
    <message>
        <source>Single</source>
        <translation>Simples</translation>
    </message>
    <message>
        <source>1.5 Lines</source>
        <translation>1,5 Linhas</translation>
    </message>
    <message>
        <source>Double</source>
        <translation>Duplo</translation>
    </message>
    <message>
        <source>Proportional</source>
        <translation>Proporcional</translation>
    </message>
    <message>
        <source>Height:</source>
        <translation>Altura:</translation>
    </message>
    <message>
        <source>Paragraph Spacing</source>
        <translation>Espaçamento do Parágrafo</translation>
    </message>
    <message>
        <source>Tab Width:</source>
        <translation>Largura da Tabulação:</translation>
    </message>
    <message>
        <source>New Theme</source>
        <translation>Novo Tema</translation>
    </message>
</context>
<context>
    <name>ThemeManager</name>
    <message>
        <source>Themes</source>
        <translation>Temas</translation>
    </message>
    <message>
        <source>Default</source>
        <translation>Padrão</translation>
    </message>
    <message>
        <source>Gentle Blues</source>
        <translation>Azuis Suaves</translation>
    </message>
    <message>
        <source>Old School</source>
        <translation>Velha Escola</translation>
    </message>
    <message>
        <source>Space Dreams</source>
        <translation>Sonhos do Espaço</translation>
    </message>
    <message>
        <source>Writing Desk</source>
        <translation>Escrivaninha</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Duplicate</source>
        <translation>Duplicar</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Personalizado</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Editar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
    <message>
        <source>Import</source>
        <translation>Importar</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>Exportar</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete theme &apos;%1&apos;?</source>
        <translation>Eliminar o tema &quot;%1&quot;?</translation>
    </message>
    <message>
        <source>Themes (%1)</source>
        <translation>Temas (%1)</translation>
    </message>
    <message>
        <source>Import Theme</source>
        <translation>Importar Tema</translation>
    </message>
    <message>
        <source>Export Theme</source>
        <translation>Exportar Tema</translation>
    </message>
    <message>
        <source>Bitter Skies</source>
        <translation>Céus Penetrantes</translation>
    </message>
    <message>
        <source>Enchantment</source>
        <translation>Encantamento</translation>
    </message>
    <message>
        <source>Spy Games</source>
        <translation>Jogos de Espiões</translation>
    </message>
    <message>
        <source>Tranquility</source>
        <translation>Tranquilidade</translation>
    </message>
</context>
<context>
    <name>Timer</name>
    <message>
        <source>&lt;b&gt;%1&lt;/b&gt; - %2</source>
        <translation>&lt;b&gt;%1&lt;/b&gt; - %2</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Delete timer?</source>
        <translation>Eliminar o cronómetro?</translation>
    </message>
    <message>
        <source>&lt;b&gt;Words:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Palavras:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Pages:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Páginas:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Paragraphs:&lt;/b&gt; %L1</source>
        <translation>&lt;b&gt;Parágrafos:&lt;/b&gt; %L1</translation>
    </message>
    <message>
        <source>&lt;b&gt;Characters:&lt;/b&gt; %L1 / %L2</source>
        <translation>&lt;b&gt;Caracteres:&lt;/b&gt; %L1 / %L2</translation>
    </message>
    <message>
        <source>Set Delay</source>
        <translation>Definir o Atraso</translation>
    </message>
    <message>
        <source>Set Time</source>
        <translation>Definir a Hora</translation>
    </message>
    <message>
        <source>Delay:</source>
        <translation>Atraso:</translation>
    </message>
    <message>
        <source>Time:</source>
        <translation>Hora:</translation>
    </message>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>Alarm</source>
        <translation>Alerta</translation>
    </message>
    <message>
        <source>Type:</source>
        <translation>Tipo:</translation>
    </message>
    <message>
        <source>Memo:</source>
        <translation>Nota :</translation>
    </message>
    <message>
        <source>Edit</source>
        <translation>Alterar</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Eliminar</translation>
    </message>
</context>
<context>
    <name>TimerDisplay</name>
    <message>
        <source>HH:mm:ss</source>
        <translation>HH:mm:ss</translation>
    </message>
    <message>
        <source>No timers running</source>
        <translation>Nenhum cronómetro acionado</translation>
    </message>
</context>
<context>
    <name>TimerManager</name>
    <message>
        <source>Timers</source>
        <translation>Cronómetros</translation>
    </message>
    <message>
        <source>New</source>
        <translation>Novo</translation>
    </message>
    <message>
        <source>Recent</source>
        <translation>Recente</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Pergunta</translation>
    </message>
    <message>
        <source>Cancel editing timers?</source>
        <translation>Cancelar a edição dos cronómetros?</translation>
    </message>
    <message>
        <source>+HH:mm:ss</source>
        <translation>+HH:mm:ss</translation>
    </message>
    <message>
        <source>%1 - %2</source>
        <translation>%1 - %2</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Loading themes</source>
        <translation>A carregar temas</translation>
    </message>
    <message>
        <source>Loading sounds</source>
        <translation>A carregar efeitos sonoros</translation>
    </message>
    <message>
        <source>Untitled</source>
        <translation>Sem título</translation>
    </message>
    <message>
        <source>Open File</source>
        <translation>Abrir Ficheiro</translation>
    </message>
    <message>
        <source>About FocusWriter</source>
        <translation>Sobre o FocusWriter</translation>
    </message>
    <message>
        <source>FocusWriter</source>
        <translation>FocusWriter</translation>
    </message>
    <message>
        <source>A simple fullscreen word processor</source>
        <translation>Um processador de texto simples em ecrã completo</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2008-%1 Graeme Gott</source>
        <translation>Direitos de Autor &amp;copy; 2008-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=%1&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Lançado sob a licença &lt;a href=%1&gt;GPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Uses icons from the &lt;a href=%1&gt;Oxygen&lt;/a&gt; icon theme</source>
        <translation>Utiliza ícones do tema &lt;a href=%1&gt;Oxygen&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Used under the &lt;a href=%1&gt;LGPL 3&lt;/a&gt; license</source>
        <translation>Utilizados sob a licença &lt;a href=%1&gt;LGPL 3&lt;/a&gt;</translation>
    </message>
    <message>
        <source>Characters: %L1 / %L2</source>
        <translation>Caracteres: %L1 / %L2</translation>
    </message>
    <message>
        <source>Pages: %L1</source>
        <translation>Páginas: %L1</translation>
    </message>
    <message>
        <source>Paragraphs: %L1</source>
        <translation>Parágrafos: %L1</translation>
    </message>
    <message>
        <source>Words: %L1</source>
        <translation>Palavras: %L1</translation>
    </message>
    <message>
        <source>Opening %1</source>
        <translation>A abrir %1</translation>
    </message>
    <message>
        <source>(Untitled %1)</source>
        <translation>(Sem título %1)</translation>
    </message>
    <message>
        <source>List all documents</source>
        <translation>Listar todos os documentos</translation>
    </message>
    <message>
        <source>Switch to Next Document</source>
        <translation>Mudar para o Documento Seguinte</translation>
    </message>
    <message>
        <source>Switch to Previous Document</source>
        <translation>Mudar para o Documento Anterior</translation>
    </message>
    <message>
        <source>Switch to First Document</source>
        <translation>Mudar para o Primeiro Documento</translation>
    </message>
    <message>
        <source>Switch to Last Document</source>
        <translation>Mudar para o Último Documento</translation>
    </message>
    <message>
        <source>Switch to Document %1</source>
        <translation>Mudar para o Documento &quot;%1&quot;</translation>
    </message>
    <message>
        <source>Loading settings</source>
        <translation>A carregar as configurações</translation>
    </message>
    <message>
        <source>Emergency cache is not writable.</source>
        <translation>Não é possível gravar nos ficheiros temporários de emergência.</translation>
    </message>
    <message>
        <source>Warning</source>
        <translation>Atenção</translation>
    </message>
    <message>
        <source>FocusWriter was not shut down cleanly.</source>
        <translation>O FocusWriter não encerrou corretamente.</translation>
    </message>
    <message>
        <source>Restore from the emergency cache?</source>
        <translation>Recuperar dados dos ficheiros temporários de emergência?</translation>
    </message>
    <message>
        <source>Some files could not be opened.</source>
        <translation>Alguns ficheiros não puderam ser abertos.</translation>
    </message>
    <message>
        <source>Some files were opened Read-Only.</source>
        <translation>Alguns ficheiros foram abertos no modo de Apenas Leitura.</translation>
    </message>
    <message>
        <source>&apos;%1&apos; is newer than the cached copy.</source>
        <translation>&quot;%1&quot; é mais recente do que a cópia presente nos ficheiros temporários</translation>
    </message>
    <message>
        <source>Overwrite newer file?</source>
        <translation>Gravar por cima do ficheiro mais recente?</translation>
    </message>
    <message>
        <source>Save Changes?</source>
        <translation>Guardar Alterações?</translation>
    </message>
    <message>
        <source>Save changes to the file &apos;%1&apos; before closing?</source>
        <translation>Guardar alterações no ficheiro &quot;%1&quot; antes de encerrar?</translation>
    </message>
    <message>
        <source>Your changes will be lost if you don&apos;t save them.</source>
        <translation>As alterações serão perdidas se não forem guardadas.</translation>
    </message>
    <message>
        <source>Unable to load typewriter sounds.</source>
        <translation>Não foi possível carregar os sons de ruídos de máquina de escrever.</translation>
    </message>
    <message>
        <source>&amp;File</source>
        <translation>&amp;Ficheiro</translation>
    </message>
    <message>
        <source>&amp;New</source>
        <translation>&amp;Novo</translation>
    </message>
    <message>
        <source>&amp;Open...</source>
        <translation>&amp;Abrir...</translation>
    </message>
    <message>
        <source>Reloa&amp;d</source>
        <translation>Carrega&amp;r Novamente</translation>
    </message>
    <message>
        <source>&amp;Save</source>
        <translation>&amp;Guardar</translation>
    </message>
    <message>
        <source>Save &amp;As...</source>
        <translation>Guardar &amp;Como...</translation>
    </message>
    <message>
        <source>&amp;Rename...</source>
        <translation>&amp;Mudar o Nome...</translation>
    </message>
    <message>
        <source>Save A&amp;ll</source>
        <translation>Guardar T&amp;udo</translation>
    </message>
    <message>
        <source>Manage Sessions</source>
        <translation>Gerir as Sessões</translation>
    </message>
    <message>
        <source>New Session</source>
        <translation>Nova Sessão</translation>
    </message>
    <message>
        <source>&amp;Print...</source>
        <translation>&amp;Imprimir...</translation>
    </message>
    <message>
        <source>&amp;Close</source>
        <translation>&amp;Fechar</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Sair</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Edit</source>
        <translation>&amp;Editar</translation>
    </message>
    <message>
        <source>&amp;Undo</source>
        <translation>&amp;Desfazer</translation>
    </message>
    <message>
        <source>&amp;Redo</source>
        <translation>&amp;Refazer</translation>
    </message>
    <message>
        <source>Cu&amp;t</source>
        <translation>Corta&amp;r</translation>
    </message>
    <message>
        <source>&amp;Copy</source>
        <translation>&amp;Copiar</translation>
    </message>
    <message>
        <source>&amp;Paste</source>
        <translation>&amp;Colar</translation>
    </message>
    <message>
        <source>Paste &amp;Unformatted</source>
        <translation>Colar &amp;Sem Formatação</translation>
    </message>
    <message>
        <source>Ctrl+Shift+V</source>
        <translation>Ctrl+Shift+V</translation>
    </message>
    <message>
        <source>Select &amp;All</source>
        <translation>Selecionar &amp;Tudo</translation>
    </message>
    <message>
        <source>Select &amp;Scene</source>
        <translation>Selecionar &amp;Cena</translation>
    </message>
    <message>
        <source>Ctrl+Shift+A</source>
        <translation>Ctrl+Shift+A</translation>
    </message>
    <message>
        <source>Fo&amp;rmat</source>
        <translation>Fo&amp;rmato</translation>
    </message>
    <message>
        <source>&amp;Bold</source>
        <translation>&amp;Negrito</translation>
    </message>
    <message>
        <source>&amp;Italic</source>
        <translation>&amp;Itálico</translation>
    </message>
    <message>
        <source>&amp;Underline</source>
        <translation>&amp;Sublinhado</translation>
    </message>
    <message>
        <source>Stri&amp;kethrough</source>
        <translation>Ra&amp;surado</translation>
    </message>
    <message>
        <source>Ctrl+K</source>
        <translation>Ctrl+K</translation>
    </message>
    <message>
        <source>Sup&amp;erscript</source>
        <translation>Sobr&amp;escrito</translation>
    </message>
    <message>
        <source>Ctrl+^</source>
        <translation>Ctrl+^</translation>
    </message>
    <message>
        <source>&amp;Subscript</source>
        <translation>&amp;Subscrito</translation>
    </message>
    <message>
        <source>Ctrl+_</source>
        <translation>Ctrl+Shift+_</translation>
    </message>
    <message>
        <source>Align &amp;Left</source>
        <translation>Alinhar à &amp;Esquerda</translation>
    </message>
    <message>
        <source>Ctrl+{</source>
        <translation>Ctrl+{</translation>
    </message>
    <message>
        <source>Align &amp;Center</source>
        <translation>Alinhar ao &amp;Centro</translation>
    </message>
    <message>
        <source>Ctrl+|</source>
        <translation>Ctrl+|</translation>
    </message>
    <message>
        <source>Align &amp;Right</source>
        <translation>Alinhar à &amp;Direita</translation>
    </message>
    <message>
        <source>Ctrl+}</source>
        <translation>Ctrl+}</translation>
    </message>
    <message>
        <source>Align &amp;Justify</source>
        <translation>&amp;Justificado</translation>
    </message>
    <message>
        <source>Ctrl+J</source>
        <translation>Ctrl+J</translation>
    </message>
    <message>
        <source>&amp;Decrease Indent</source>
        <translation>&amp;Reduzir a Indentação</translation>
    </message>
    <message>
        <source>Ctrl+&lt;</source>
        <translation>Ctrl+&lt;</translation>
    </message>
    <message>
        <source>I&amp;ncrease Indent</source>
        <translation>A&amp;umentar a Indentação</translation>
    </message>
    <message>
        <source>Ctrl+&gt;</source>
        <translation>Ctrl+&gt;</translation>
    </message>
    <message>
        <source>Le&amp;ft to Right Block</source>
        <translation>&amp;Bloco de Escrita da Esquerda para a Direita</translation>
    </message>
    <message>
        <source>Ri&amp;ght to Left Block</source>
        <translation>B&amp;loco de Escrita da Direita para a Esquerda</translation>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation>&amp;Ferramentas</translation>
    </message>
    <message>
        <source>&amp;Find...</source>
        <translation>&amp;Procurar...</translation>
    </message>
    <message>
        <source>Find &amp;Next</source>
        <translation>Procurar Se&amp;guinte</translation>
    </message>
    <message>
        <source>Find Pre&amp;vious</source>
        <translation>Procurar &amp;Anterior</translation>
    </message>
    <message>
        <source>&amp;Replace...</source>
        <translation>&amp;Substituir...</translation>
    </message>
    <message>
        <source>Ctrl+R</source>
        <translation>Ctrl+S</translation>
    </message>
    <message>
        <source>Smart &amp;Quotes</source>
        <translation>&amp;Aspas Curvas e Angulares</translation>
    </message>
    <message>
        <source>Update &amp;Document</source>
        <translation>Atualizar &amp;Documento</translation>
    </message>
    <message>
        <source>Update &amp;Selection</source>
        <translation>Atualizar &amp;Seleção</translation>
    </message>
    <message>
        <source>&amp;Spelling...</source>
        <translation>&amp;Ortografia...</translation>
    </message>
    <message>
        <source>F7</source>
        <translation>F7</translation>
    </message>
    <message>
        <source>Set &amp;Language...</source>
        <translation>Definir &amp;Língua</translation>
    </message>
    <message>
        <source>&amp;Timers...</source>
        <translation>C&amp;ronómetros...</translation>
    </message>
    <message>
        <source>S&amp;ymbols...</source>
        <translation>Sí&amp;mbolos...</translation>
    </message>
    <message>
        <source>&amp;Daily Progress</source>
        <translation>&amp;Progresso Diário</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Configurações</translation>
    </message>
    <message>
        <source>Show &amp;Toolbar</source>
        <translation>Mostrar a &amp;Barra de Ferramentas</translation>
    </message>
    <message>
        <source>Show &amp;Menu Icons</source>
        <translation>&amp;Mostrar Ícones nos Menus</translation>
    </message>
    <message>
        <source>F&amp;ocused Text</source>
        <translation>Texto F&amp;ocado</translation>
    </message>
    <message>
        <source>&amp;Fullscreen</source>
        <translation>&amp;Ecrã Inteiro</translation>
    </message>
    <message>
        <source>F11</source>
        <translation>F11</translation>
    </message>
    <message>
        <source>Esc</source>
        <translation>Esc</translation>
    </message>
    <message>
        <source>M&amp;inimize</source>
        <translation>M&amp;inimizar</translation>
    </message>
    <message>
        <source>Ctrl+M</source>
        <translation>Ctrl+M</translation>
    </message>
    <message>
        <source>&amp;Themes...</source>
        <translation>&amp;Temas...</translation>
    </message>
    <message>
        <source>&amp;Preferences...</source>
        <translation>&amp;Preferências...</translation>
    </message>
    <message>
        <source>Focus Off</source>
        <translation>Desligar o Foco</translation>
    </message>
    <message>
        <source>Focus One Line</source>
        <translation>Focar 1 Linha</translation>
    </message>
    <message>
        <source>Focus Three Lines</source>
        <translation>Focar 3 Linhas</translation>
    </message>
    <message>
        <source>&amp;Paragraph</source>
        <translation>&amp;Parágrafo</translation>
    </message>
    <message>
        <source>Focus Paragraph</source>
        <translation>Focar Parágrafo</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>A&amp;juda</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Língua do Programa...</translation>
    </message>
    <message>
        <source>Some files were unsupported and could not be opened.</source>
        <translation>Alguns ficheiros não são suportados e não puderam ser abertos.</translation>
    </message>
    <message>
        <source>&amp;Off</source>
        <translation>&amp;Desligado</translation>
    </message>
    <message>
        <source>One &amp;Line</source>
        <translation>&amp;1 Linha</translation>
    </message>
    <message>
        <source>&amp;Three Lines</source>
        <translation>&amp;3 Linhas</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Sobre</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Sobre o &amp;Qt</translation>
    </message>
    <message>
        <source>Pa&amp;ge Setup...</source>
        <translation>Confi&amp;guração da Página...</translation>
    </message>
    <message>
        <source>&amp;Heading</source>
        <translation>&amp;Cabeçalho</translation>
    </message>
    <message>
        <source>Heading &amp;1</source>
        <translation>Cabeçalho &amp;1</translation>
    </message>
    <message>
        <source>Heading &amp;2</source>
        <translation>Cabeçalho &amp;2</translation>
    </message>
    <message>
        <source>Heading &amp;3</source>
        <translation>Cabeçalho &amp;3</translation>
    </message>
    <message>
        <source>Heading &amp;4</source>
        <translation>Cabeçalho &amp;4</translation>
    </message>
    <message>
        <source>Heading &amp;5</source>
        <translation>Cabeçalho &amp;5</translation>
    </message>
    <message>
        <source>Heading &amp;6</source>
        <translation>Cabeçalho &amp;6</translation>
    </message>
    <message>
        <source>&amp;Normal</source>
        <translation>&amp;Normal</translation>
    </message>
    <message>
        <source>Update Document Smart Quotes</source>
        <translation>Atualizar Aspas Curvas e Angulares do Documento</translation>
    </message>
    <message>
        <source>Update Selection Smart Quotes</source>
        <translation>Atualizar Aspas Curvas e Angulares da Seleção</translation>
    </message>
    <message>
        <source>Ctrl+Shift+`</source>
        <translation>Ctrl+Shift+`</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Files to open in current session.</source>
        <translation>Ficheiros a abrir na sessão em curso.</translation>
    </message>
</context>
</TS>
